inline time_t DateTime::time() const
{
    return d_time;
}
